@@ -6,7 +6,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Commands
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014, 2020 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -62,7 +62,7 @@ import Network.URI (parseURIReference)
 
 import Control.Monad.Trans (MonadTrans(..))
 import Control.Monad.State (modify, gets)
-import Control.Monad (liftM, when)
+import Control.Monad (when)
 
 import qualified Data.Set as S
 import qualified Data.Text.Lazy as T
@@ -197,7 +197,7 @@ defURI = "http://id.ninebynine.org/2003/Swish/"
 calculateBaseURI ::
   Maybe FilePath -- ^ file name
   -> SwishStateIO QName -- ^ base URI
-calculateBaseURI Nothing = fromMaybe defURI `liftM` gets base
+calculateBaseURI Nothing = gets (fromMaybe defURI . base)
 calculateBaseURI (Just fnam) =
   case parseURIReference fnam of
     Just furi -> do
@@ -385,7 +385,7 @@ swishCreateWriteableFile (Just fnam) = do
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012 Douglas Burke  
+--    2011, 2012, 2014, 2020 Douglas Burke  
 --  All rights reserved.
 --
 --  This file is part of Swish.
