@@ -7,7 +7,7 @@
 -- |
 --  Module      :  GraphMatch
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2016, 2018 Douglas Burke
+--                 2011, 2012, 2016, 2018, 2020 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -471,7 +471,7 @@ assignLabelMap ns lmap = S.foldl' (flip assignLabelMap1) lmap ns
 
 assignLabelMap1 :: (Label lb) => lb -> LabelMap lb -> LabelMap lb
 assignLabelMap1 lab (LabelMap g lvs) = 
-    LabelMap g $ M.insertWith (flip const) lab (g, initVal lab) lvs
+    LabelMap g $ M.insertWith (const id) lab (g, initVal lab) lvs
 
 --  Calculate initial value for a node
 
@@ -671,7 +671,7 @@ graphMapEq lmap = (==) `on` graphMap lmap
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2016, 2018 Douglas Burke
+--    2011, 2012, 2016, 2018, 2020 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
