@@ -5,7 +5,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  QName
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2020 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -41,8 +41,6 @@ module Swish.QName
     )
     where
 
-import Control.Monad (liftM)
-
 import Data.Char (isAscii)
 import Data.Maybe (fromMaybe)
 import Data.Interned (intern, unintern)
@@ -209,12 +207,12 @@ qnameFromURI uri =
       start = QName (intern uri)
   in case uf of
        "#"    -> q0
-       '#':xs -> start (uri {uriFragment = "#"}) `liftM` newLName (T.pack xs)
+       '#':xs -> start (uri {uriFragment = "#"}) `fmap` newLName (T.pack xs)
        ""     -> case break (=='/') (reverse up) of
                    ("",_) -> q0 -- path ends in / or is empty
                    (_,"") -> q0 -- path contains no /
                    (rlname,rpath) -> 
-                       start (uri {uriPath = reverse rpath}) `liftM` 
+                       start (uri {uriPath = reverse rpath}) `fmap` 
                        newLName (T.pack (reverse rlname))
 
        -- e -> error $ "Unexpected: uri=" ++ show uri ++ " has fragment='" ++ show e ++ "'" 
@@ -275,7 +273,7 @@ emptyAuth = Just $ URIAuth "" "" ""
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013 Douglas Burke
+--    2011, 2012, 2013, 2020 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
