@@ -6,7 +6,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Integer
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -62,7 +62,6 @@ import Swish.RDF.Vocabulary
     , namespaceXsdType
     )
 
-import Control.Monad (liftM)
 import Data.Maybe (maybeToList)
 
 #if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
@@ -224,7 +223,7 @@ c2 = (.) . (.)
 
 relXsdIntegerPower :: DatatypeRel Integer
 relXsdIntegerPower = mkIntRel3maybe "power" (const True)
-    [ ( const True, [ (liftM (:[]) `c2` intPower,1,2) ] )
+    [ ( const True, [ (fmap (:[]) `c2` intPower,1,2) ] )
     , ( const True, [ ] )
     , ( (>=0),      [ ] )
     ]
@@ -511,7 +510,7 @@ rulesXsdIntegerBuilder =
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012 Douglas Burke
+--    2011, 2012, 2014, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
