@@ -7,7 +7,7 @@
 -- |
 --  Module      :  Internal
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013, 2014, 2016, 2018 Douglas Burke
+--                 2011, 2012, 2013, 2014, 2016, 2018, 2020 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -74,7 +74,6 @@ import Swish.RDF.Graph (labels, getArcs
                        )
 import Swish.RDF.Vocabulary (LanguageTag, fromLangTag, xsdBoolean, xsdDecimal, xsdInteger, xsdDouble)
 
-import Control.Monad (liftM)
 import Control.Monad.State (State, get, gets, modify, put)
 
 import Data.List (foldl', groupBy, intersperse, partition)
@@ -177,7 +176,7 @@ if the result is not empty.
 -}
 
 hasMore :: (a -> [b]) -> State a Bool
-hasMore lens = (not . null . lens) `liftM` get
+hasMore lens = gets (not . null . lens)
 
 
 {-|
@@ -499,7 +498,7 @@ formatPrefixes_ ::
     -> NamespaceMap
     -> State a B.Builder
 formatPrefixes_ nextLine pmap = 
-    mconcat `liftM` mapM nextLine (formatPrefixLines pmap)
+    mconcat `fmap` mapM nextLine (formatPrefixLines pmap)
 
 formatGraph_ :: 
     (B.Builder -> State a ()) -- set indent
@@ -640,7 +639,7 @@ insertBnode_ subjs props objs updateState formatProperties lbl = do
   put $ updateState ost rsubjs rprops []
   flag <- hasMore props
   txt <- if flag
-         then (`mappend` "\n") `liftM` formatProperties lbl ""
+         then (`mappend` "\n") `fmap` formatProperties lbl ""
          else return ""
 
   -- restore the original data (where appropriate)
@@ -702,7 +701,7 @@ extractList_ subjs props setSubjs setProps lctxt ln = do
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013, 2014, 2016, 2018 Douglas Burke
+--    2011, 2012, 2013, 2014, 2016, 2018, 2020 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
