@@ -9,7 +9,7 @@
 -- |
 --  Module      :  Graph
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013, 2014, 2015, 2016, 2018 Douglas Burke
+--                 2011, 2012, 2013, 2014, 2015, 2016, 2018, 2020 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -1388,7 +1388,7 @@ grShow p g =
     "Graph, formulae: " ++ showForm ++ "\n" ++
     p ++ "arcs: " ++ showArcs p g
     where
-        showForm = foldr ((++) . (pp ++) . show) "" fml
+        showForm = concatMap ((pp ++) . show) fml
         fml = map (uncurry Formula) $ M.assocs (getFormulae g) -- NOTE: want to just show 'name :- graph'
         pp = "\n    " ++ p
 
@@ -1595,7 +1595,7 @@ toRDFGraph arcs =
       ns = mapMaybe (fmap getScopeNamespace . getNS) $ S.toList lbls
       nsmap = foldl'
               (\m ins -> let (p,u) = getNamespaceTuple ins
-                         in M.insertWith (flip const) p u m)
+                         in M.insertWith (const id) p u m)
               emptyNamespaceMap ns
   
   in mempty { namespaces = nsmap, statements = arcs }
@@ -1619,7 +1619,7 @@ updateRDFGraph gr as = gr { statements=as }
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013, 2014, 2015, 2016, 2018 Douglas Burke
+--    2011, 2012, 2013, 2014, 2015, 2016, 2018, 2020 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
