@@ -6,7 +6,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Turtle
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014, 2018 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014, 2018, 2020 Douglas Burke
 --  License     :  GPL V2
 -- 
 --  Maintainer  :  Douglas Burke
@@ -866,8 +866,7 @@ _exponent :: TurtleParser L.Text
 _exponent = do
   e <- char 'e' <|> char 'E'
   ms <- _leadingSign
-  ep <- _integer
-  return $ L.cons e $ addSign ms ep
+  L.cons e . addSign ms <$> _integer
 
 {-
 [22]	STRING_LITERAL_QUOTE	::=	'"' ([^#x22#x5C#xA#xD] | ECHAR | UCHAR)* '"'
@@ -1036,8 +1035,7 @@ _plx = _percent <|> (L.singleton <$> _pnLocalEsc)
 _percent = do
   ichar '%'
   a <- _hex
-  b <- _hex
-  return $ L.cons '%' $ L.cons a $ L.singleton b
+  L.cons '%' . L.cons a . L.singleton <$> _hex
 
 _hex, _pnLocalEsc :: TurtleParser Char
 _hex = satisfy isHexDigit
@@ -1049,7 +1047,7 @@ _pnLocalEscChars = "_~.-!$&'()*+,;=/?#@%"
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013, 2014, 2018 Douglas Burke
+--    2011, 2012, 2013, 2014, 2018, 2020 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
