@@ -6,7 +6,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Vocabulary
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2014, 2021 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -71,6 +71,8 @@ import Swish.RDF.Vocabulary.RDF
 import Swish.RDF.Vocabulary.OWL
 import Swish.RDF.Vocabulary.XSD
 
+import Control.Monad (guard)
+
 import Data.Char (isDigit, isAsciiLower)
 import Data.List (isPrefixOf)
 import Data.List.NonEmpty (NonEmpty(..))
@@ -222,15 +224,18 @@ instance Ord LanguageTag where
 -- or obey any other syntactical restriction than given above.
 -- 
 toLangTag :: T.Text -> Maybe LanguageTag
-toLangTag lbl = 
-    let tag = T.toLower lbl
-        toks = T.split (=='-') tag
-    in if all (\s -> let l = T.length s in l > 0 && l < 9) toks
-       then let primtag : subtags = toks
-            in if T.all isAsciiLower primtag && all (T.all (\c -> isAsciiLower c || isDigit c)) subtags
-               then Just $ LanguageTag lbl (NE.fromList toks)
-               else Nothing
-       else Nothing
+toLangTag lbl = do
+  let tag = T.toLower lbl
+      toks = T.split (=='-') tag
+  guard (all (\s -> let l = T.length s in l > 0 && l < 9) toks)
+
+  -- T.split can't return [] but the compiler doesn't know this
+  case toks of
+    primtag : subtags -> do
+      guard (T.all isAsciiLower primtag && all (T.all (\c -> isAsciiLower c || isDigit c)) subtags)
+      pure $ LanguageTag lbl (NE.fromList toks)
+
+    [] -> Nothing
 
 -- | Convert a language tag back into text form.
 fromLangTag :: LanguageTag -> T.Text
@@ -309,7 +314,7 @@ defaultBase = makeNSScopedName namespaceDefault "base"
 
 --------------------------------------------------------------------------------
 --
---  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011 Douglas Burke
+--  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2014, 2021 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
