@@ -6,7 +6,7 @@
 --------------------------------------------------------------------------------
 {- |
 Module      :  Script
-Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014, 2018 Douglas Burke
+Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014, 2018, 2020 Douglas Burke
 License     :  GPL V2
 
 Maintainer  :  Douglas Burke
@@ -125,7 +125,7 @@ import Swish.Utils.ListHelpers (flist)
 
 import Text.ParserCombinators.Poly.StateText
 
-import Control.Monad (unless, when, liftM, void)
+import Control.Monad (unless, when, void)
 import Control.Monad.State (modify, gets, lift)
 
 #if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
@@ -246,8 +246,7 @@ writeGraph =
             ; n <- n3SymLex
             ; let gs = ssGetList n :: SwishStateIO (Either String [RDFGraph])
             ; muri <- maybeURI
-            ; c <- commentText
-            ; return $ ssWriteList muri gs c
+            ; ssWriteList muri gs <$> commentText
             }
 
 --  @merge ( name* ) => name
@@ -317,8 +316,7 @@ checkProofCmd =
             ; igf <- formulaExpr
             ; sts <- many checkStep
             ; commandName "@result"
-            ; rgf <- formulaExpr
-            ; return $ ssCheckProof pn sns igf sts rgf
+            ; ssCheckProof pn sns igf sts <$> formulaExpr
             }
 
 checkStep ::
@@ -502,7 +500,7 @@ ssReadGraph muri =
         Left  es -> Left es
         Right is -> parseN3 is (muri >>= qnameFromURI)
         
-  in gf `liftM` getResourceData muri
+  in gf `fmap` getResourceData muri
 
 ssWriteList ::
     Maybe URI -> SwishStateIO (Either String [RDFGraph]) -> String
@@ -882,11 +880,8 @@ ssBwdChain sn rn cgf an prefs =
 --  (Add logic to separate filenames from URIs, and
 --  attempt HTTP GET, or similar.)
 getResourceData :: Maybe URI -> SwishStateIO (Either String L.Text)
-getResourceData muri =
-    case muri of
-        Nothing  -> fromStdin
-        Just uri -> fromUri uri
-    where
+getResourceData = maybe fromStdin fromUri 
+  where
     fromStdin = Right <$> lift LIO.getContents
     fromUri = fromFile
     fromFile uri | uriScheme uri == "file:" = Right `fmap` lift (LIO.readFile $ uriPath uri)
@@ -1486,7 +1481,7 @@ and the output is
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2014, 2018 Douglas Burke
+--    2011, 2012, 2014, 2018, 2020 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
